pub struct AstCache { /* private fields */ }Expand description
A SQLite-backed cache of compaction results, keyed by content hash.
Implementations
Sourceimpl AstCache
impl AstCache
Sourcepub fn outline_cached(
&self,
compactor: &mut Compactor,
source: &str,
) -> Result<CompactResult>
pub fn outline_cached( &self, compactor: &mut Compactor, source: &str, ) -> Result<CompactResult>
Compact source, returning a cached result on a content-hash hit and only
invoking the Tree-sitter parser on a miss.